getRegisteredDeviceToken method
Method to get the device token registered with the Zixflow SDK. Returns a Future that resolves to the device token registered with Zixflow SDK.
Implementation
@override
Future<String?> getRegisteredDeviceToken() {
return methodChannel
.invokeNativeMethod<String>(NativeMethods.getRegisteredDeviceToken);
}