ZixflowMessagingPushPlatform class abstract

The default instance of ZixflowMessagingPushPlatform to use

Platform-specific plugins should override this with their own platform-specific class that extends ZixflowMessagingPushPlatform when they register themselves.

Defaults to ZixflowMessagingPushMethodChannel

Inheritance
  • Object
  • PlatformInterface
  • ZixflowMessagingPushPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRegisteredDeviceToken() Future<String?>
Method to get the device token registered with the Zixflow SDK. Returns a Future that resolves to the device token registered with Zixflow SDK.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBackgroundMessageReceived(Map<String, dynamic> message) Future<bool>
Handles push notification received when app is background. Since FCM itself displays the notification when app is background, this method makes it easier to determine whether the notification should be displayed or not.
onMessageReceived(Map<String, dynamic> message, {bool handleNotificationTrigger = true}) Future<bool>
Processes push notification received outside the Zixflow SDK. The method displays notification on device and tracks metrics for push notification.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ZixflowMessagingPushPlatform
getter/setter pair