Zixflow class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearIdentify() → void
Call this function to stop identifying a person.
deleteDeviceToken() → void
Delete a device token that was previously registered with Zixflow
identify({required String userId, Map<String, dynamic> traits = const {}}) → void
Identify a person using a unique userId, eg. email id. Note that you can identify only 1 profile at a time. In case, multiple identifiers are attempted to be identified, then the last identified profile will be removed automatically.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerDeviceToken({required String deviceToken}) → void
Register a new device token with Zixflow, associated with the current active user. If there is no active user, this will fail to register the device
screen({required String title, Map<String, dynamic> properties = const {}}) → void
Track screen events to record the screens a user visits
setDeviceAttributes({required Map<String, dynamic> attributes}) → void
Use this function to send custom device attributes such as app preferences, timezone etc
setProfileAttributes({required Map<String, dynamic> attributes}) → void
Set custom user profile information such as user preference, specific user actions etc
toString() String
A string representation of this object.
inherited
track({required String name, Map<String, dynamic> properties = const {}}) → void
To track user events like loggedIn, addedItemToCart etc. You may also track events with additional yet optional data.
trackMetric({required String deliveryID, required String deviceToken, required MetricEvent event}) → void
Track a push metric

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inAppMessaging ZixflowMessagingInAppPlatform
Access in-app messaging functionality
no setter
instance Zixflow
Get the singleton instance of Zixflow
no setter
location ZixflowLocationPlatform
Access location functionality
no setter
pushMessaging ZixflowMessagingPushPlatform
Access push messaging functionality
no setter

Static Methods

createInstance({ZixflowPlatform? platform, ZixflowMessagingPushPlatform? pushMessaging, ZixflowMessagingInAppPlatform? inAppMessaging, ZixflowLocationPlatform? location}) Zixflow
For testing: create a new instance with mock implementations
initialize({required ZixflowConfig config}) Future<void>
To initialize the plugin
reset() → void