identify method

void identify({
  1. required String userId,
  2. Map<String, dynamic> traits = const {},
})

Identify a person using a unique userId, eg. email id. Note that you can identify only 1 profile at a time. In case, multiple identifiers are attempted to be identified, then the last identified profile will be removed automatically.

@param userId unique identifier for a profile @param traits (Optional) params to set profile attributes

Implementation

void identify(
    {required String userId, Map<String, dynamic> traits = const {}}) {
  return _platform.identify(
      userId: userId, traits: traits.excludeNullValues());
}