registerDeviceToken method
Register a new device token with Zixflow, associated with the current active user. If there is no active user, this will fail to register the device
Implementation
void registerDeviceToken({required String deviceToken}) {
return _platform.registerDeviceToken(deviceToken: deviceToken);
}