screen method
Track screen events to record the screens a user visits
@param name name of the screen user visited @param attributes (Optional) params to be sent with event
Implementation
void screen(
{required String title, Map<String, dynamic> properties = const {}}) {
return _platform.screen(
title: title, properties: properties.excludeNullValues());
}